@@ -4,19 +4,19 @@ test_that("the constructor keeps the state space", {
 })
 
 test_that("the empty constructor returns a zero depth tree", {
-  expect_identical(depth(new_ctx_tree(c(0, 1))), 0)
+  expect_identical(depth(new_ctx_tree(c(0, 1))), 0L)
 })
 
 test_that("the depth is calculated correctly", {
-  expect_identical(depth(build_demo_tree(1:3, 4)), 4)
-  expect_identical(depth(build_demo_tree(1:4, 2)), 2)
-  expect_identical(depth(build_demo_tree(c("a", "b"), 3)), 3)
+  expect_identical(depth(build_demo_tree(1:3, 4)), 4L)
+  expect_identical(depth(build_demo_tree(1:4, 2)), 2L)
+  expect_identical(depth(build_demo_tree(c("a", "b"), 3)), 3L)
 })
 
 test_that("the context number is calculted correctly", {
-  expect_identical(context_number(build_demo_tree(1:3, 4)), 3^4)
-  expect_identical(context_number(build_demo_tree(1:4, 2)), 4^2)
-  expect_identical(context_number(build_demo_tree(c("a", "b"), 3)), 2^3)
+  expect_identical(context_number(build_demo_tree(1:3, 4)), as.integer(3^4))
+  expect_identical(context_number(build_demo_tree(1:4, 2)), as.integer(4^2))
+  expect_identical(context_number(build_demo_tree(c("a", "b"), 3)), as.integer(2^3))
 })
 
 test_that("the context tree has the correct class", {
